@@ -1,9 +1,9 @@
 from pprint import pformat
-from typing import Any, Dict, List, Optional, Type
+from typing import Any, Dict, List, Optional
 
 from pytezos.context.impl import ExecutionContext
 from pytezos.context.mixin import ContextMixin  # type: ignore
-from pytezos.contract.call import ContractCall, ContractCallResult, skip_nones
+from pytezos.contract.call import ContractCallResult, skip_nones
 from pytezos.jupyter import get_class_docstring
 from pytezos.logging import logger
 from pytezos.michelson.micheline import MichelsonRuntimeError
@@ -153,6 +153,16 @@ class ContractViewCall(ContextMixin):
             logger.info(self.__doc__)
             raise ValueError(f'Unexpected storage object: {pformat(storage)}', *e.args) from e
 
+    def _get_storage(self, storage=None):
+        if storage is None:
+            storage_expr = self.context.get_storage_value(self.address)
+            if storage_expr is None:
+                return self._encode_storage()
+            else:
+                return storage_expr
+        else:
+            return self._encode_storage(storage)
+
     def _prepare_query(
         self,
         parameters=None,
@@ -212,10 +222,10 @@ class ContractViewCall(ContextMixin):
     def storage_view(self, storage=None):
         """Get return value of an off-chain view.
 
-        :param storage: initial storage as Python object, leave None if you want to generate a dummy one
+        :param storage: override current contract storage (as Python object)
         :returns: Decoded return value
         """
-        parameters = format_view_params(param_expr=self.param_expr, storage_expr=self._encode_storage(storage))
+        parameters = format_view_params(param_expr=self.param_expr, storage_expr=self._get_storage(storage))
         script = format_view_script(
             param_ty_expr=self.param_ty_expr,
             storage_ty_expr=self.context.storage_expr,
@@ -233,18 +243,23 @@ class ContractViewCall(ContextMixin):
             raise error
         return storage  # type: ignore
 
-    def onchain_view(self, storage=None, balance=None):
+    def onchain_view(self, storage=None, balance=None, view_results: Optional[Dict[str, Any]] = None):
         """Get return value of an on-chain view.
 
-        :param storage: initial storage as Python object, leave None if you want to generate a dummy one
+        :param storage: override current contract storage (as Python object)
         :param balance: patch BALANCE
+        :param view_results: patch VIEW calls (keys must be string "address%view", values => Python objects)
         :returns: Decoded return value
         """
         ret, stdout, error = Interpreter.run_view(
             name=self.name,
             parameter=self.param_expr,
-            storage=self._encode_storage(storage),
-            context=self._spawn_context(balance=balance, script={**self.context.script, 'storage': self._encode_storage(storage)}),
+            storage=self._get_storage(storage),
+            context=self._spawn_context(
+                balance=balance,
+                script={**self.context.script, 'storage': self._encode_storage(storage)},  # type: ignore
+                view_results=view_results,
+            ),
         )
         if error:
             logger.debug('\n'.join(stdout))
